# Dataset package

```{eval-rst}
.. automodule:: sec_certs.dataset
    :no-members:
```

This documentation doesn't provide full API reference for all members of `dataset` package. Instead, it concentrattes on the Dataset that are immediately exposed to the users. Namely, we focus on `CCDataset` and `FIPSDataset`.

```{tip}
The examples related to this package can be found at [common criteria notebook](./../notebooks/examples/common_criteria.ipynb) and [fips notebook](./../notebooks/examples/fips.ipynb).
```

## CCDataset

```{eval-rst}
.. currentmodule:: sec_certs.dataset
.. autoclass:: CCDataset
    :members:
```

## FIPSDataset

```{eval-rst}
.. currentmodule:: sec_certs.dataset
.. autoclass:: FIPSDataset
    :members:
```
